==> webkit2gtk_2.48.6.orig.tar.xz: webkitgtk-2.48.6/Source/WebCore/rendering/updating/RenderTreeUpdaterGeneratedContent.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "RenderStyleConstants.h"
#include "RenderTreeUpdater.h"
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class Element;
class RenderQuote;

class RenderTreeUpdater::GeneratedContent {
    WTF_MAKE_TZONE_ALLOCATED(GeneratedContent);
public:
    GeneratedContent(RenderTreeUpdater&);

    void updateBackdropRenderer(RenderElement&, StyleDifference minimalStyleDifference);
    void updatePseudoElement(Element&, const Style::ElementUpdate&, PseudoId);
    void updateRemainingQuotes();
    void updateCounters();
    void updateWritingSuggestionsRenderer(RenderElement&, StyleDifference minimalStyleDifference);

    static void removeBeforePseudoElement(Element&, RenderTreeBuilder&);
    static void removeAfterPseudoElement(Element&, RenderTreeBuilder&);

private:
    void updateQuotesUpTo(RenderQuote*);
    
    bool needsPseudoElement(const RenderStyle*);

    RenderTreeUpdater& m_updater;
    SingleThreadWeakPtr<RenderQuote> m_previousUpdatedQuote;
};

}

==> webkit2gtk_2.50.2.orig.tar.xz: webkitgtk-2.50.2/Source/WebCore/rendering/updating/RenderTreeUpdaterGeneratedContent.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "RenderStyleConstants.h"
#include "RenderTreeUpdater.h"
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class Element;
class RenderQuote;

class RenderTreeUpdater::GeneratedContent {
    WTF_MAKE_TZONE_ALLOCATED(GeneratedContent);
public:
    GeneratedContent(RenderTreeUpdater&);

    void updateBackdropRenderer(RenderElement&, StyleDifference minimalStyleDifference);
    void updateBeforeOrAfterPseudoElement(Element&, const Style::ElementUpdate&, PseudoId);
    void updateRemainingQuotes();
    void updateCounters();
    void updateWritingSuggestionsRenderer(RenderElement&, StyleDifference minimalStyleDifference);

    static void removeBeforePseudoElement(Element&, RenderTreeBuilder&);
    static void removeAfterPseudoElement(Element&, RenderTreeBuilder&);

private:
    void updateQuotesUpTo(RenderQuote*);
    
    bool needsPseudoElement(const RenderStyle*);

    RenderTreeUpdater& m_updater;
    SingleThreadWeakPtr<RenderQuote> m_previousUpdatedQuote;
};

}
